==> monodevelop_1.0+dfsg.orig.tar.gz: monodevelop-1.0+dfsg/src/addins/MonoDevelop.Gettext/MonoDevelop.Gettext/PropertyProvider.cs <==
//
// PropertyProvider.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.ComponentModel;

using MonoDevelop.Projects;
using MonoDevelop.DesignerSupport;

namespace MonoDevelop.Gettext
{
	public class PropertyProvider : IPropertyProvider
	{
		public bool SupportsObject (object o)
		{
			return o is ProjectFile;
		}

		public object CreateProvider (object o)
		{
			return new ProjectFileWrapper ((ProjectFile)o);
		}
		
		public class ProjectFileWrapper: CustomDescriptor
		{
			ProjectFile file;
			
			public ProjectFileWrapper (ProjectFile file)
			{
				this.file = file;
			}
			
			const string scanForTranslationsProperty = "Gettext.ScanForTranslations";
			[Category ("Gettext translation")]
			[DisplayName ("Scan for translations")]
			[Description ("Include this file in the translation scan.")]
			public bool ScanForTranslations {
				get {
					object result = file.ExtendedProperties [scanForTranslationsProperty];
					return result == null ? true : (bool)result;
				}
				set {
					if (value) {
						file.ExtendedProperties.Remove (scanForTranslationsProperty);
					} else {
						file.ExtendedProperties [scanForTranslationsProperty] = value;
					}
				}
			}
		}
		
	}
}

==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/addins/MonoDevelop.Gettext/MonoDevelop.Gettext/PropertyProvider.cs <==
//
// PropertyProvider.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

using MonoDevelop.Core;
using MonoDevelop.Projects;
using MonoDevelop.DesignerSupport;

namespace MonoDevelop.Gettext
{
	public class PropertyProvider : IPropertyProvider
	{
		public bool SupportsObject (object o)
		{
			return o is ProjectFile;
		}

		public object CreateProvider (object o)
		{
			return new ProjectFileWrapper ((ProjectFile)o);
		}
		
		public class ProjectFileWrapper: CustomDescriptor
		{
			ProjectFile file;
			
			public ProjectFileWrapper (ProjectFile file)
			{
				this.file = file;
			}
			
			const string scanForTranslationsProperty = "Gettext.ScanForTranslations";
			[LocalizedCategory ("Gettext translation")]
			[LocalizedDisplayName ("Scan for translations")]
			[LocalizedDescription ("Include this file in the translation scan.")]
			public bool ScanForTranslations {
				get {
					object result = file.ExtendedProperties [scanForTranslationsProperty];
					return result == null ? true : (bool)result;
				}
				set {
					if (value) {
						file.ExtendedProperties.Remove (scanForTranslationsProperty);
					} else {
						file.ExtendedProperties [scanForTranslationsProperty] = value;
					}
				}
			}
		}
		
	}
}
